@@ -1,8 +1,5 @@
 #include <RcppClock.h>
 
-//[[Rcpp::plugins(openmp)]]
-#include <omp.h>
-
 // a simple timing example
 int fib(int n) {
   return ((n <= 1) ? n : fib(n - 1) + fib(n - 2));
